@@ -3,8 +3,9 @@
 use strict;
 use warnings;
 
-use FindBin;
-use lib "$FindBin::Bin/../lib";
+use FindBin; # only for this example - load local Udev::FFI module
+use lib "$FindBin::Bin/../lib"; # only for this example - load local Udev::FFI module
+
 use Udev::FFI;
 use Udev::FFI::Devnum qw(:all); #import major, minor and mkdev
 
